import style from '../css/SensorData.module.css';
import globalStyle from '../css/App.module.css';
import { Line } from 'react-chartjs-2';
import moment from 'moment';
import { Chart, CategoryScale, LinearScale, PointElement, LineElement } from "chart.js";

export default function SensorData(props) {
    const sensor = props.sensor;
    if(!sensor.data) return (<div data-testid="noDataSensor" className={globalStyle.center}><span>Il n y'a pas de données pour ce sensor</span></div>)
    return generateData(sensor);
}

function generateData(sensor) {
    const data = sensor.data;
    const type = sensor.type;
    switch(type) {
        case 'DOOR':
            return generateElementForDoor(sensor);
        case 'TEMPERATURE': {
          const lastLabel = sensor.data.labels[sensor.data.labels.length-1];
          const lastValue = sensor.data.values[sensor.data.values.length-1];
          const lastDate  = moment(lastLabel);
          return (
            <div className={style.sensorData}>
              <span className={style.lastData}>Dernier enregistrement de température {lastDate.isValid() ? `(${lastDate.format("l LT")})` : ''}: {lastValue}°{sensor.unit || 'C'}</span>
              {generateChart(sensor, 12, 14, 30)}
            </div>
          );
        }
        case 'FAN_SPEED': {
          const lastLabel = sensor.data.labels[sensor.data.labels.length-1];
          const lastValue = sensor.data.values[sensor.data.values.length-1];
          const lastDate  = moment(lastLabel);
          return (
            <div className={style.sensorData}>
              <span className={style.lastData}>Dernière vitesse enregistrée {lastDate.isValid() ? `(${lastDate.format("l LT")})` : ''}: {lastValue}RPM</span>
              {generateChart(sensor, 20, 0)}
            </div>
          );
        }
        case 'HUMIDITY': {
          const lastLabel = sensor.data.labels[sensor.data.labels.length - 1];
          const lastValue = sensor.data.values[sensor.data.values.length - 1];
          const lastDate = moment(lastLabel);
          return (
            <div className={style.sensorData}>
              <span className={style.lastData}>Dernier enregistrement d'humidité {lastDate.isValid() ? `(${lastDate.format("LT")})` : ''}: {lastValue}%</span>
              {generateChart(sensor, 36, 0, 100)}
            </div>
          )
        }
        case 'LIGHT': {
          return generateElementForLight(sensor);
        }
        case 'SWITCH': {
          return generateElementForSwitch(sensor);
        }
        default: return (<pre data-testid="invalidSensor">{JSON.stringify(data, null, 4)}</pre>);
    }
}

function generateElementForDoor(sensor) {
    const isOpened = sensor.data.value === 1;
    const imgSrc = isOpened ? '/openedDoor.jpeg' : '/closedDoor.jpeg';
    const imgAlt = isOpened ? 'Porte ouverte' : 'Porte fermer';
    const textState = isOpened ? 'ouverte' : 'fermée';
    return (
      <div className={style.doorData}>
        <span className={style.doorCaption}>La porte est {textState}</span>
        <br/>
        <img className={style.doorImg} alt={imgAlt} src={imgSrc}/>
      </div>
    )
  }